(self.webpackJsonp=self.webpackJsonp||[]).push([[98],{690:function(e,t,i){"use strict";i.r(t);var a=i(0),n=(i(160),i(1));!function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.routerOptions={defaultPage:"configuration",cacheAll:!0,preloadAll:!0,routes:{configuration:{tag:"ha-config-zha",load:function(){return Promise.all([i.e(0),i.e(1),i.e(3),i.e(7),i.e(131)]).then(i.bind(null,675))}},add:{tag:"zha-add-devices-page",load:function(){return Promise.all([i.e(0),i.e(1),i.e(3),i.e(7),i.e(130)]).then(i.bind(null,672))}}}},t}Object(a.d)(t,e),t.prototype.updatePageEl=function(e){e.route=this.routeTail,e.hass=this.hass,e.isWide=this.isWide},Object(a.c)([Object(n.g)()],t.prototype,"hass",void 0),Object(a.c)([Object(n.g)()],t.prototype,"isWide",void 0),t=Object(a.c)([Object(n.d)("zha-config-panel")],t)}(i(133).a)}}]);
//# sourceMappingURL=chunk.4aef0b2430e09abb7f9f.js.map