(self.webpackJsonp=self.webpackJsonp||[]).push([[96],{689:function(e,t,a){"use strict";a.r(t);var s=a(3),i=(a(159),a(0)),o=a(133);let c=class extends o.a{constructor(){super(...arguments),this.routerOptions={defaultPage:"configuration",cacheAll:!0,preloadAll:!0,routes:{configuration:{tag:"ha-config-zha",load:()=>Promise.all([a.e(0),a.e(1),a.e(3),a.e(6),a.e(142)]).then(a.bind(null,674))},add:{tag:"zha-add-devices-page",load:()=>Promise.all([a.e(0),a.e(1),a.e(3),a.e(6),a.e(141)]).then(a.bind(null,672))}}}}updatePageEl(e){e.route=this.routeTail,e.hass=this.hass,e.isWide=this.isWide}};Object(s.c)([Object(i.g)()],c.prototype,"hass",void 0),Object(s.c)([Object(i.g)()],c.prototype,"isWide",void 0),c=Object(s.c)([Object(i.d)("zha-config-panel")],c)}}]);
//# sourceMappingURL=chunk.7f33bc7910ba1e2f9606.js.map