(self.webpackJsonp=self.webpackJsonp||[]).push([[57],{197:function(e,n,i){"use strict";var t=i(240);i.d(n,"a",function(){return a});var a=Object(t.a)({types:{"entity-id":function(e){return"string"!=typeof e?"entity id should be a string":!!e.includes(".")||"entity id should be in the format 'domain.entity'"},icon:function(e){return"string"!=typeof e?"icon should be a string":!!e.includes(":")||"icon should be in the format 'mdi:icon'"}}})},203:function(e,n,i){"use strict";i.d(n,"a",function(){return r});var t,a=i(0),c=i(1),r=Object(c.f)(t||(t=Object(a.f)(["\n  <style>\n    ha-switch {\n      padding: 16px 0;\n    }\n    .side-by-side {\n      display: flex;\n    }\n    .side-by-side > * {\n      flex: 1;\n      padding-right: 4px;\n    }\n    .suffix {\n      margin: 0 8px;\n    }\n  </style>\n"],["\n  <style>\n    ha-switch {\n      padding: 16px 0;\n    }\n    .side-by-side {\n      display: flex;\n    }\n    .side-by-side > * {\n      flex: 1;\n      padding-right: 4px;\n    }\n    .suffix {\n      margin: 0 8px;\n    }\n  </style>\n"])))},700:function(e,n,i){"use strict";i.r(n),i.d(n,"HuiIframeCardEditor",function(){return p});var t,a,c=i(0),r=i(1),l=(i(93),i(197)),o=i(18),s=i(203),u=Object(l.a)({type:"string",title:"string?",url:"string?",aspect_ratio:"string?"}),p=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return Object(c.d)(n,e),n.prototype.setConfig=function(e){e=u(e),this._config=e},Object.defineProperty(n.prototype,"_title",{get:function(){return this._config.title||""},enumerable:!0,configurable:!0}),Object.defineProperty(n.prototype,"_url",{get:function(){return this._config.url||""},enumerable:!0,configurable:!0}),Object.defineProperty(n.prototype,"_aspect_ratio",{get:function(){return this._config.aspect_ratio||""},enumerable:!0,configurable:!0}),n.prototype.render=function(){return this.hass?Object(r.f)(a||(a=Object(c.f)(["\n      ",'\n      <div class="card-config">\n        <paper-input\n          .label="'," (",')"\n          .value="','"\n          .configValue="','"\n          @value-changed="','"\n        ></paper-input>\n        <div class="side-by-side">\n          <paper-input\n            .label="'," (",')"\n            .value="','"\n            .configValue="','"\n            @value-changed="','"\n          ></paper-input>\n          <paper-input\n            .label="'," (",')"\n            type="number"\n            .value="','"\n            .configValue="','"\n            @value-changed="','"\n          ></paper-input>\n        </div>\n      </div>\n    '],["\n      ",'\n      <div class="card-config">\n        <paper-input\n          .label="'," (",')"\n          .value="','"\n          .configValue="','"\n          @value-changed="','"\n        ></paper-input>\n        <div class="side-by-side">\n          <paper-input\n            .label="'," (",')"\n            .value="','"\n            .configValue="','"\n            @value-changed="','"\n          ></paper-input>\n          <paper-input\n            .label="'," (",')"\n            type="number"\n            .value="','"\n            .configValue="','"\n            @value-changed="','"\n          ></paper-input>\n        </div>\n      </div>\n    '])),s.a,this.hass.localize("ui.panel.lovelace.editor.card.generic.url"),this.hass.localize("ui.panel.lovelace.editor.card.config.required"),this._url,"url",this._valueChanged,this.hass.localize("ui.panel.lovelace.editor.card.generic.title"),this.hass.localize("ui.panel.lovelace.editor.card.config.optional"),this._title,"title",this._valueChanged,this.hass.localize("ui.panel.lovelace.editor.card.generic.aspect_ratio"),this.hass.localize("ui.panel.lovelace.editor.card.config.optional"),Number(this._aspect_ratio.replace("%","")),"aspect_ratio",this._valueChanged):Object(r.f)(t||(t=Object(c.f)([""],[""])))},n.prototype._valueChanged=function(e){var n;if(this._config&&this.hass){var i=e.target,t=i.value;"aspect_ratio"===i.configValue&&i.value&&(t+="%"),this["_"+i.configValue]!==t&&(i.configValue&&(""===i.value?delete this._config[i.configValue]:this._config=Object(c.a)(Object(c.a)({},this._config),((n={})[i.configValue]=t,n))),Object(o.a)(this,"config-changed",{config:this._config}))}},Object(c.c)([Object(r.g)()],n.prototype,"hass",void 0),Object(c.c)([Object(r.g)()],n.prototype,"_config",void 0),n=Object(c.c)([Object(r.d)("hui-iframe-card-editor")],n)}(r.a)}}]);
//# sourceMappingURL=chunk.1ca6b49bbd7a894e7071.js.map