(self.webpackJsonp=self.webpackJsonp||[]).push([[62],{704:function(n,i,e){"use strict";e.r(i),e.d(i,"HuiPictureCardEditor",function(){return g});var a,t,o=e(0),c=e(1),l=(e(93),e(403),e(197)),s=e(279),r=e(18),u=e(203),h=Object(l.a)({type:"string",image:"string?",tap_action:l.a.optional(s.a),hold_action:l.a.optional(s.a)}),g=function(n){function i(){return null!==n&&n.apply(this,arguments)||this}return Object(o.d)(i,n),i.prototype.setConfig=function(n){n=h(n),this._config=n},Object.defineProperty(i.prototype,"_image",{get:function(){return this._config.image||""},enumerable:!0,configurable:!0}),Object.defineProperty(i.prototype,"_tap_action",{get:function(){return this._config.tap_action||{action:"none"}},enumerable:!0,configurable:!0}),Object.defineProperty(i.prototype,"_hold_action",{get:function(){return this._config.hold_action||{action:"none"}},enumerable:!0,configurable:!0}),i.prototype.render=function(){if(!this.hass)return Object(c.f)(a||(a=Object(o.f)([""],[""])));var n=["navigate","url","call-service","none"];return Object(c.f)(t||(t=Object(o.f)(["\n      ",'\n      <div class="card-config">\n        <paper-input\n          .label="'," (",')"\n          .value="','"\n          .configValue="','"\n          @value-changed="','"\n        ></paper-input>\n        <div class="side-by-side">\n          <hui-action-editor\n            .label="'," (",')"\n            .hass="','"\n            .config="','"\n            .actions="','"\n            .configValue="','"\n            @action-changed="','"\n          ></hui-action-editor>\n          <hui-action-editor\n            .label="'," (",')"\n            .hass="','"\n            .config="','"\n            .actions="','"\n            .configValue="','"\n            @action-changed="','"\n          ></hui-action-editor>\n        </div>\n      </div>\n    '],["\n      ",'\n      <div class="card-config">\n        <paper-input\n          .label="'," (",')"\n          .value="','"\n          .configValue="','"\n          @value-changed="','"\n        ></paper-input>\n        <div class="side-by-side">\n          <hui-action-editor\n            .label="'," (",')"\n            .hass="','"\n            .config="','"\n            .actions="','"\n            .configValue="','"\n            @action-changed="','"\n          ></hui-action-editor>\n          <hui-action-editor\n            .label="'," (",')"\n            .hass="','"\n            .config="','"\n            .actions="','"\n            .configValue="','"\n            @action-changed="','"\n          ></hui-action-editor>\n        </div>\n      </div>\n    '])),u.a,this.hass.localize("ui.panel.lovelace.editor.card.generic.image"),this.hass.localize("ui.panel.lovelace.editor.card.config.required"),this._image,"image",this._valueChanged,this.hass.localize("ui.panel.lovelace.editor.card.generic.tap_action"),this.hass.localize("ui.panel.lovelace.editor.card.config.optional"),this.hass,this._tap_action,n,"tap_action",this._valueChanged,this.hass.localize("ui.panel.lovelace.editor.card.generic.hold_action"),this.hass.localize("ui.panel.lovelace.editor.card.config.optional"),this.hass,this._hold_action,n,"hold_action",this._valueChanged)},i.prototype._valueChanged=function(n){var i;if(this._config&&this.hass){var e=n.target;this["_"+e.configValue]!==e.value&&this["_"+e.configValue]!==e.config&&(e.configValue&&(""===e.value?delete this._config[e.configValue]:this._config=Object(o.a)(Object(o.a)({},this._config),((i={})[e.configValue]=e.value?e.value:e.config,i))),Object(r.a)(this,"config-changed",{config:this._config}))}},Object(o.c)([Object(c.g)()],i.prototype,"hass",void 0),Object(o.c)([Object(c.g)()],i.prototype,"_config",void 0),i=Object(o.c)([Object(c.d)("hui-picture-card-editor")],i)}(c.a)}}]);
//# sourceMappingURL=chunk.b2b847fe99e7822de9a9.js.map