(self.webpackJsonp=self.webpackJsonp||[]).push([[51],{714:function(n,t,e){"use strict";e.r(t),e.d(t,"HuiEmptyStateCard",function(){return s});var a,c,i,o=e(0),r=e(1),s=(e(178),function(n){function t(){return null!==n&&n.apply(this,arguments)||this}return Object(o.d)(t,n),t.prototype.getCardSize=function(){return 2},t.prototype.setConfig=function(n){},t.prototype.render=function(){return this.hass?Object(r.f)(c||(c=Object(o.f)(['\n      <ha-card\n        .header="','"\n      >\n        <div class="card-content">\n          ','\n        </div>\n        <div class="card-actions">\n          <a href="/config/integrations">\n            <mwc-button>\n              ',"\n            </mwc-button>\n          </a>\n        </div>\n      </header-card>\n    "],['\n      <ha-card\n        .header="','"\n      >\n        <div class="card-content">\n          ','\n        </div>\n        <div class="card-actions">\n          <a href="/config/integrations">\n            <mwc-button>\n              ',"\n            </mwc-button>\n          </a>\n        </div>\n      </header-card>\n    "])),this.hass.localize("ui.panel.lovelace.cards.empty_state.title"),this.hass.localize("ui.panel.lovelace.cards.empty_state.no_devices"),this.hass.localize("ui.panel.lovelace.cards.empty_state.go_to_integrations_page")):Object(r.f)(a||(a=Object(o.f)([""],[""])))},Object.defineProperty(t,"styles",{get:function(){return Object(r.c)(i||(i=Object(o.f)(["\n      .content {\n        margin-top: -1em;\n        padding: 16px;\n      }\n\n      .card-actions a {\n        text-decoration: none;\n      }\n\n      mwc-button {\n        margin-left: -8px;\n      }\n    "],["\n      .content {\n        margin-top: -1em;\n        padding: 16px;\n      }\n\n      .card-actions a {\n        text-decoration: none;\n      }\n\n      mwc-button {\n        margin-left: -8px;\n      }\n    "])))},enumerable:!0,configurable:!0}),Object(o.c)([Object(r.g)()],t.prototype,"hass",void 0),t=Object(o.c)([Object(r.d)("hui-empty-state-card")],t)}(r.a))}}]);
//# sourceMappingURL=chunk.39793481e698814d4d7f.js.map